Deadlines.

- [X] mark a single task as having a deadline
- [X] embellish deadlines with custom urgency windows
- [X] filter output based on urgency
- [X] summarise urgency?
- [X] rework sample.md to example.md, and use it for docs/usage.md
- [X] completed/cancelled in sixth category
